/* automatically generated from pulseaudio-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (pulseaudio_dialog_ui)
#endif
#ifdef __GNUC__
static const char pulseaudio_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char pulseaudio_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.11\"/"
  "><object class=\"GtkAdjustment\" id=\"adjustment-volume-step\"><propert"
  "y name=\"lower\">1</property><property name=\"upper\">50</property><pro"
  "perty name=\"value\">5</property><property name=\"step_increment\">1</p"
  "roperty><property name=\"page_increment\">10</property></object><object"
  " class=\"GtkAdjustment\" id=\"adjustment-max-volume\"><property name=\""
  "lower\">1</property><property name=\"upper\">300</property><property na"
  "me=\"value\">150</property><property name=\"step_increment\">1</propert"
  "y><property name=\"page_increment\">10</property></object><object class"
  "=\"GtkImage\" id=\"image1\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"icon_name\""
  ">xfce4-pulseaudio-plugin</property></object><object class=\"GtkImage\" "
  "id=\"image2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"icon_name\">edit-clear</"
  "property></object><object class=\"GtkListStore\" id=\"liststore1\"><col"
  "umns><column type=\"GIcon\"/><column type=\"gchararray\"/><column type="
  "\"gboolean\"/><column type=\"gboolean\"/><column type=\"gchararray\"/><"
  "/columns></object><object class=\"GtkListStore\" id=\"notifications-sto"
  "re\"><columns><column type=\"gchararray\"/></columns><data><row><col id"
  "=\"0\" translatable=\"yes\">None</col></row><row><col id=\"0\" translat"
  "able=\"yes\">All</col></row><row><col id=\"0\" translatable=\"yes\">Out"
  "put only</col></row><row><col id=\"0\" translatable=\"yes\">Input only<"
  "/col></row></data></object><object class=\"XfceTitledDialog\" id=\"dial"
  "og\"><property name=\"can_focus\">False</property><property name=\"titl"
  "e\" translatable=\"yes\">PulseAudio Panel Plugin</property><property na"
  "me=\"default_width\">425</property><property name=\"default_height\">52"
  "5</property><property name=\"icon_name\">gtk-properties</property><prop"
  "erty name=\"type_hint\">normal</property><child internal-child=\"vbox\""
  "><object class=\"GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">2</p"
  "roperty><child internal-child=\"action_area\"><object class=\"GtkButton"
  "Box\" id=\"dialog-action_area2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"layou"
  "t_style\">end</property><child><object class=\"GtkButton\" id=\"close-b"
  "utton\"><property name=\"label\">gtk-close</property><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"receives_default\">True</property><property name=\"use_st"
  "ock\">True</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">False</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkButton\""
  " id=\"help-button\"><property name=\"label\">gtk-help</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">True</property><property na"
  "me=\"use_stock\">True</property></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">False</property><property "
  "name=\"position\">1</property><property name=\"secondary\">True</proper"
  "ty></packing></child></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">True</property><property name=\"pack_"
  "type\">end</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkNotebook\" id=\"sections\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"border_width\">6</property><child><object class=\""
  "GtkBox\" id=\"section_general_content\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"border_width\">12</property><property name=\"orientation\">vertical</"
  "property><property name=\"spacing\">18</property><child><object class=\""
  "GtkFrame\" id=\"frame1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"label_xalign\""
  ">0</property><property name=\"shadow_type\">none</property><child><obje"
  "ct class=\"GtkAlignment\" id=\"alignment1\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"top_padding\">6</property><property name=\"left_padding\">12</pro"
  "perty><child><object class=\"GtkBox\" id=\"vbox2\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"orientation\">vertical</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkCheckButton\" id=\"checkbutton-k"
  "eyboard-shortcuts\"><property name=\"label\" translatable=\"yes\">Enabl"
  "e keyboard _shortcuts for volume control</property><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">False</property><property name=\"tooltip"
  "_text\" translatable=\"yes\">Enables volume control using multimedia ke"
  "ys. Make sure no other application that listens to these keys (e.g. xfc"
  "e4-volumed) is running in the background.</property><property name=\"ha"
  "lign\">start</property><property name=\"use_underline\">True</property>"
  "<property name=\"draw_indicator\">True</property></object><packing><pro"
  "perty name=\"expand\">True</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">0</property></packing></child><child><"
  "object class=\"GtkCheckButton\" id=\"checkbutton-play-sound\"><property"
  " name=\"label\" translatable=\"yes\">Play system _sound when volume cha"
  "nges</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">False"
  "</property><property name=\"tooltip_text\" translatable=\"yes\">Enables"
  " audio feedback when using multimedia keys to change the volume.</prope"
  "rty><property name=\"halign\">start</property><property name=\"use_unde"
  "rline\">True</property><property name=\"draw_indicator\">True</property"
  "></object><packing><property name=\"expand\">True</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">1</property></p"
  "acking></child><child><object class=\"GtkCheckButton\" id=\"checkbutton"
  "-rec-indicator-persistent\"><property name=\"label\" translatable=\"yes"
  "\">Always display the recording _indicator</property><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"receives_default\">False</property><property name=\"halig"
  "n\">start</property><property name=\"use_underline\">True</property><pr"
  "operty name=\"draw_indicator\">True</property></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">2</property></packing></child><child><obj"
  "ect class=\"GtkBox\" id=\"vbox2-hbox2\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"spacing\">6</property><child><object class=\"GtkLabel\" id=\"label5\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">Show vol"
  "ume _notifications:</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"mnemonic_widget\">combobox-notifications</prope"
  "rty></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">0</property"
  "></packing></child><child><object class=\"GtkComboBox\" id=\"combobox-n"
  "otifications\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"tooltip_text\" translat"
  "able=\"yes\">Mute/unmute is notified in all modes except \"None\"</prop"
  "erty><property name=\"model\">notifications-store</property><child><obj"
  "ect class=\"GtkCellRendererText\" id=\"cb_text_render\"/><attributes><a"
  "ttribute name=\"text\">0</attribute></attributes></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "></object><packing><property name=\"expand\">True</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">3</property></p"
  "acking></child><child><object class=\"GtkBox\" id=\"vbox2-hbox1\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"tooltip_text\" translatable=\"yes\">Step si"
  "ze used when adjusting volume with mouse wheel or hotkeys.</property><p"
  "roperty name=\"spacing\">6</property><child><object class=\"GtkLabel\" "
  "id=\"label4\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"label\" translatable=\"y"
  "es\">_Volume step:</property><property name=\"use_underline\">True</pro"
  "perty><property name=\"mnemonic_widget\">spinbutton-volume-step</proper"
  "ty></object><packing><property name=\"expand\">False</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">0</property>"
  "</packing></child><child><object class=\"GtkSpinButton\" id=\"spinbutto"
  "n-volume-step\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"hexpand\">True</propert"
  "y><property name=\"halign\">start</property><property name=\"max_length"
  "\">2</property><property name=\"width_chars\">2</property><property nam"
  "e=\"max_width_chars\">3</property><property name=\"caps_lock_warning\">"
  "False</property><property name=\"adjustment\">adjustment-volume-step</p"
  "roperty><property name=\"climb_rate\">1</property><property name=\"snap"
  "_to_ticks\">True</property></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">True</property><p"
  "roperty name=\"position\">3</property></packing></child><child><object "
  "class=\"GtkBox\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"spacing\">6</property"
  "><child><object class=\"GtkLabel\" id=\"label6\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"label\" translatable=\"yes\">M_aximum volume:</property><pro"
  "perty name=\"use_underline\">True</property><property name=\"mnemonic_w"
  "idget\">spinbutton-max-volume</property></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child><child><object c"
  "lass=\"GtkSpinButton\" id=\"spinbutton-max-volume\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"hexpand\">True</property><property name=\"halign\">start</"
  "property><property name=\"max_length\">3</property><property name=\"wid"
  "th_chars\">3</property><property name=\"max_width_chars\">4</property><"
  "property name=\"caps_lock_warning\">False</property><property name=\"ad"
  "justment\">adjustment-max-volume</property><property name=\"climb_rate\""
  ">1</property><property name=\"snap_to_ticks\">True</property></object><"
  "packing><property name=\"expand\">False</property><property name=\"fill"
  "\">True</property><property name=\"position\">1</property></packing></c"
  "hild></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">4</propert"
  "y></packing></child></object></child></object></child><child type=\"lab"
  "el\"><object class=\"GtkLabel\" id=\"label1\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">Behaviour</property><attributes><at"
  "tribute name=\"weight\" value=\"bold\"/></attributes></object></child><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"position\">0</property></pa"
  "cking></child><child><object class=\"GtkFrame\" id=\"frame2\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"label_xalign\">0</property><property name=\"sha"
  "dow_type\">none</property><child><object class=\"GtkAlignment\" id=\"al"
  "ignment2\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"top_padding\">6</property><"
  "property name=\"left_padding\">12</property><child><object class=\"GtkG"
  "rid\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"row_spacing\">6</property><prope"
  "rty name=\"column_spacing\">12</property><child><object class=\"GtkLabe"
  "l\" id=\"label2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Audio _Mixer</property><property name=\"use_underline\">True</"
  "property></object><packing><property name=\"left_attach\">0</property><"
  "property name=\"top_attach\">0</property></packing></child><child><obje"
  "ct class=\"GtkEntry\" id=\"entry-mixer-command\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"tooltip_text\" translatable=\"yes\">Audio mixer command that "
  "can be executed from the context menu, e.g. \"pavucontrol\", \"unity-co"
  "ntrol-center sound\".</property><property name=\"hexpand\">True</proper"
  "ty><property name=\"invisible_char\">\342\200\242</property><property n"
  "ame=\"primary_icon_activatable\">False</property><property name=\"secon"
  "dary_icon_activatable\">False</property></object><packing><property nam"
  "e=\"left_attach\">1</property><property name=\"top_attach\">0</property"
  "></packing></child><child><object class=\"GtkButton\" id=\"button-run-m"
  "ixer\"><property name=\"label\" translatable=\"yes\">_Run Audio Mixer.."
  ".</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"halign\">start</property><property name=\"image"
  "\">image1</property><property name=\"use_underline\">True</property></o"
  "bject><packing><property name=\"left_attach\">0</property><property nam"
  "e=\"top_attach\">1</property><property name=\"width\">2</property></pac"
  "king></child></object></child></object></child><child type=\"label\"><o"
  "bject class=\"GtkLabel\" id=\"label3\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "label\" translatable=\"yes\">Sound Settings</property><attributes><attr"
  "ibute name=\"weight\" value=\"bold\"/></attributes></object></child></o"
  "bject><packing><property name=\"expand\">False</property><property name"
  "=\"fill\">True</property><property name=\"position\">1</property></pack"
  "ing></child></object></child><child type=\"tab\"><object class=\"GtkLab"
  "el\" id=\"section_general\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"label\" tr"
  "anslatable=\"yes\">General</property></object><packing><property name=\""
  "tab_fill\">False</property></packing></child><child><object class=\"Gtk"
  "Box\" id=\"section_mp_content\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"margin"
  "_left\">10</property><property name=\"margin_right\">10</property><prop"
  "erty name=\"margin_top\">7</property><property name=\"margin_bottom\">1"
  "2</property><property name=\"orientation\">vertical</property><property"
  " name=\"spacing\">18</property><child><object class=\"GtkBox\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"margin_left\">2</property><property name=\"mar"
  "gin_right\">2</property><property name=\"orientation\">vertical</proper"
  "ty><child><object class=\"GtkBox\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"spa"
  "cing\">12</property><child><object class=\"GtkLabel\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">Control Playback of Media "
  "Players</property><attributes><attribute name=\"weight\" value=\"bold\""
  "/></attributes></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkSwitch\" id=\"s"
  "witch-mpris-support\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"pack_type\">end</property><property name=\"position\">1</prop"
  "erty></packing></child></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">0</property></packing></child><child><object class=\"GtkAlignme"
  "nt\" id=\"section_mp_content_1\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"left_"
  "padding\">12</property><child><object class=\"GtkBox\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"orientation\">vertical</property><property name=\"spaci"
  "ng\">6</property><child><object class=\"GtkCheckButton\" id=\"checkbutt"
  "on-multimedia-keys\"><property name=\"label\" translatable=\"yes\">Enab"
  "le multimedia keys for playback control</property><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">False</property><property name=\"halign\""
  ">start</property><property name=\"draw_indicator\">True</property></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkCheckButton\" id=\"checkbutton-multi"
  "media-keys-to-all\"><property name=\"label\" translatable=\"yes\">Send "
  "multimedia keys to all players</property><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">True</property><property name="
  "\"receives_default\">False</property><property name=\"halign\">start</p"
  "roperty><property name=\"draw_indicator\">True</property></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "><child><object class=\"GtkCheckButton\" id=\"checkbutton-wnck\"><prope"
  "rty name=\"label\" translatable=\"yes\">Enable experimental window focu"
  "s support</property><property name=\"visible\">True</property><property"
  " name=\"can_focus\">True</property><property name=\"receives_default\">"
  "False</property><property name=\"halign\">start</property><property nam"
  "e=\"draw_indicator\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">2</property></packing></child></object></child></o"
  "bject><packing><property name=\"expand\">False</property><property name"
  "=\"fill\">True</property><property name=\"position\">1</property></pack"
  "ing></child></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">True</property><property name=\"position\">0</"
  "property></packing></child><child><object class=\"GtkFrame\" id=\"secti"
  "on_mp_content_2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"margin_left\">2</pro"
  "perty><property name=\"margin_right\">2</property><property name=\"marg"
  "in_bottom\">12</property><property name=\"label_xalign\">0</property><p"
  "roperty name=\"shadow_type\">none</property><child><object class=\"GtkA"
  "lignment\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"top_padding\">6</property><"
  "property name=\"left_padding\">12</property><child><object class=\"GtkB"
  "ox\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"orientation\">vertical</property>"
  "<property name=\"spacing\">6</property><child><object class=\"GtkScroll"
  "edWindow\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"shadow_type\">in</property><"
  "child><object class=\"GtkTreeView\" id=\"player_tree_view\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">True</prope"
  "rty><property name=\"model\">liststore1</property><property name=\"head"
  "ers_clickable\">False</property><property name=\"enable_search\">False<"
  "/property><property name=\"show_expanders\">False</property><child inte"
  "rnal-child=\"selection\"><object class=\"GtkTreeSelection\"/></child><c"
  "hild><object class=\"GtkTreeViewColumn\" id=\"col_icon\"><child><object"
  " class=\"GtkCellRendererPixbuf\" id=\"col_icon_renderer\"/><attributes>"
  "<attribute name=\"gicon\">0</attribute></attributes></child></object></"
  "child><child><object class=\"GtkTreeViewColumn\" id=\"col_label\"><prop"
  "erty name=\"title\" translatable=\"yes\">Name</property><property name="
  "\"expand\">True</property><child><object class=\"GtkCellRendererText\" "
  "id=\"col_label_renderer\"/><attributes><attribute name=\"text\">1</attr"
  "ibute></attributes></child></object></child><child><object class=\"GtkT"
  "reeViewColumn\" id=\"col_persistent\"><property name=\"title\" translat"
  "able=\"yes\">Persistent</property><child><object class=\"GtkCellRendere"
  "rToggle\" id=\"col_persistent_renderer\"/><attributes><attribute name=\""
  "active\">2</attribute></attributes></child></object></child><child><obj"
  "ect class=\"GtkTreeViewColumn\" id=\"col_ignored\"><property name=\"tit"
  "le\" translatable=\"yes\">Ignored</property><child><object class=\"GtkC"
  "ellRendererToggle\" id=\"col_ignored_renderer\"/><attributes><attribute"
  " name=\"active\">3</attribute></attributes></child></object></child></o"
  "bject></child></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkButton\" id=\"cle"
  "ar_players\"><property name=\"label\" translatable=\"yes\">Clear Known "
  "Items</property><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"receives_default\">True"
  "</property><property name=\"halign\">start</property><property name=\"i"
  "mage\">image2</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">False</property><property name=\"p"
  "osition\">1</property></packing></child><child><object class=\"GtkRevea"
  "ler\" id=\"restart_revealer\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><child><object class=\"Gt"
  "kLabel\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"halign\">start</property><pro"
  "perty name=\"label\" translatable=\"yes\">Please restart the players to"
  " make them visible again.</property><property name=\"wrap\">True</prope"
  "rty><property name=\"xalign\">0</property><attributes><attribute name=\""
  "style\" value=\"italic\"/></attributes></object></child></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">2</property></packing></child>"
  "</object></child></object></child><child type=\"label\"><object class=\""
  "GtkLabel\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Known Media Players</property><attributes><attribute name=\"weight\" v"
  "alue=\"bold\"/></attributes></object></child></object><packing><propert"
  "y name=\"expand\">True</property><property name=\"fill\">True</property"
  "><property name=\"position\">1</property></packing></child></object><pa"
  "cking><property name=\"position\">1</property></packing></child><child "
  "type=\"tab\"><object class=\"GtkLabel\" id=\"section_mp\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">Media Players</propert"
  "y></object><packing><property name=\"position\">1</property><property n"
  "ame=\"tab_fill\">False</property></packing></child><child><placeholder/"
  "></child><child type=\"tab\"><placeholder/></child></object><packing><p"
  "roperty name=\"expand\">True</property><property name=\"fill\">True</pr"
  "operty><property name=\"position\">1</property></packing></child></obje"
  "ct></child><action-widgets><action-widget response=\"0\">close-button</"
  "action-widget><action-widget response=\"0\">help-button</action-widget>"
  "</action-widgets></object></interface>"
};

static const unsigned pulseaudio_dialog_ui_length = 23475u;

